using System;
using System.Text.Json.Serialization;
namespace com.docusign.connect {
   using org.accordproject.cicero.runtime;
   using org.accordproject.binary;
   using concerto;
   enum EnvelopeStatusCode {
      Any,
      Voided,
      Created,
      Deleted,
      Sent,
      Delivered,
      Signed,
      Completed,
      Declined,
      TimedOut,
      Template,
      Processing,
   }

   enum RecipientStatusCode {
      Created,
      Sent,
      Delivered,
      Signed,
      Declined,
      Completed,
      FaxPending,
      AutoResponded,
   }

   enum TabTypeCode {
      InitialHere,
      SignHere,
      FullName,
      FirstName,
      LastName,
      EmailAddress,
      Company,
      Title,
      DateSigned,
      InitialHereOptional,
      EnvelopeID,
      Custom,
      SignerAttachment,
      SignHereOptional,
      Approve,
      Decline,
      SignerAttachmentOptional,
      DigitalSignature,
   }

   enum CustomTabTypeCode {
      Text,
      Checkbox,
      Radio,
      List,
      Date,
      Number,
      SSN,
      ZIP5,
      ZIP5DASH4,
      Email,
      Note,
      Formula,
   }

   enum DocumentType {
      Principal,
      CertificateOfCompletion,
      SignerAttachment,
   }

   class EnvelopeStatus : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "com.docusign.connect.EnvelopeStatus";
      public EnvelopeStatusCode status { get; set; }
      public string envelopeId { get; set; }
      public DateTime created { get; set; }
      public DateTime sent { get; set; }
      public DateTime delivered { get; set; }
      public DateTime signed { get; set; }
      public DateTime completed { get; set; }
      public DateTime declined { get; set; }
      public string email { get; set; }
   }
   class Recipient : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "com.docusign.connect.Recipient";
      public RecipientStatusCode status { get; set; }
      public string email { get; set; }
      public string userName { get; set; }
      public DateTime sent { get; set; }
      public DateTime delivered { get; set; }
      public DateTime signed { get; set; }
      public DateTime declined { get; set; }
      public string declineReason { get; set; }
      public TabStatus[] tabStatuses { get; set; }
   }
   class CustomField : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "com.docusign.connect.CustomField";
      public string name { get; set; }
      public string value { get; set; }
   }
   abstract class TabStatus : Concept {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "com.docusign.connect.TabStatus";
      public TabTypeCode tabType { get; set; }
      public string status { get; set; }
      public string tabLabel { get; set; }
      public string originalValue { get; set; }
      public DateTime signed { get; set; }
      public CustomTabTypeCode customTabType { get; set; }
   }
   class NumberTabStatus : TabStatus {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "com.docusign.connect.NumberTabStatus";
      public string tabName { get; set; }
      public float tabValue { get; set; }
   }
   class TextTabStatus : TabStatus {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "com.docusign.connect.TextTabStatus";
      public string tabName { get; set; }
      public string tabValue { get; set; }
   }
   class DateTabStatus : TabStatus {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "com.docusign.connect.DateTabStatus";
      public string tabName { get; set; }
      public DateTime tabValue { get; set; }
   }
   class BooleanTabStatus : TabStatus {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "com.docusign.connect.BooleanTabStatus";
      public string tabName { get; set; }
      public bool tabValue { get; set; }
   }
   class ListTabStatus : TabStatus {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "com.docusign.connect.ListTabStatus";
      public string[] tabNames { get; set; }
      public string tabValue { get; set; }
      public string[] listValues { get; set; }
      public string listSelectedValue { get; set; }
   }
   class Attachment : BinaryResource {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "com.docusign.connect.Attachment";
      public DocumentType docType { get; set; }
   }
   class DocuSignEnvelopeInformation : Request {
      [JsonPropertyName("$class")]
      public new string _class { get;} = "com.docusign.connect.DocuSignEnvelopeInformation";
      public EnvelopeStatus envelopeStatus { get; set; }
      public Recipient[] recipients { get; set; }
      public CustomField[] customFields { get; set; }
      public Attachment[] attachments { get; set; }
   }
}
